/*
 * Copyright 2017 Arne Vajh�j.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.script.py;

import java.io.UnsupportedEncodingException;
import java.util.List;

import dk.vajhoej.vms.call.script.LIBRTL_Script;

/**
 * Class LIBRTL_Py is a Python friendly wrapper library for LIB$ functions.
 */
public class LIBRTL_Py extends LIBRTL_Script {
	/**
	 * Call LIB$CREATE_DIR to create directory.
	 * @param dirnam directory name
	 * @return return status code
	 * @throws UnsupportedEncodingException if directory name can not be encoded
	 */
	public static Result<Void> LIB__CREATE_DIR(String dirnam) throws UnsupportedEncodingException {
		return LIB$CREATE_DIR(dirnam);
	}
	/**
	 * Call LIB$DELETE_FILE to delete file.
	 * @param fnm filename
	 * @return return status code
	 * @throws UnsupportedEncodingException if filename can not be encoded
	 */
	public static Result<Void> LIB__DELETE_FILE(String fnm) throws UnsupportedEncodingException {
		return LIB$DELETE_FILE(fnm);
	}
	/**
	 * Call LIB$DELETE_LOGICAL to delete logical.
	 * @param lognam logical name
	 * @return return status code
	 * @throws UnsupportedEncodingException if logical name can not be encoded
	 */
	public static Result<Void> LIB__DELETE_LOGICAL(String lognam) throws UnsupportedEncodingException {
		return LIB$DELETE_LOGICAL(lognam);
	}
	/**
	 * Call LIB$DELETE_SYMBOL to delete symbol.
	 * @param symnam symbol name
	 * @return return status code
	 * @throws UnsupportedEncodingException if symbol name can not be encoded
	 */
	public static Result<Void> LIB__DELETE_SYMBOL(String symnam) throws UnsupportedEncodingException {
		return LIB$DELETE_SYMBOL(symnam);
	}
	/**
	 * Call LIB$DISABLE_CTRL to disable CTRL/T or CTRL/Y.
	 * @param ctrlt disable CTRL/T
	 * @param ctrly disable CTRL/Y
	 * @return return status code
	 */
	public static Result<Void> LIB__DISABLE_CTRL(boolean ctrlt, boolean ctrly) {
		return LIB$DISABLE_CTRL(ctrlt, ctrly);
	}
	/**
	 * Call LIB$DO_COMMAND to transfer control to execution of command.
	 * @param cmd command to execute
	 * @return return status code
	 * @throws UnsupportedEncodingException if command can not be encoded
	 */
	public static Result<Void> LIB__DO_COMMAND(String cmd) throws UnsupportedEncodingException {
		return LIB$DO_COMMAND(cmd);
	}
	/**
	 * Call LIB$ENABLE_CTRL to enable CTRL/T or CTRL/Y.
	 * @param ctrlt disable CTRL/T
	 * @param ctrly disable CTRL/Y
	 * @return return status code
	 */
	public static Result<Void> LIB__ENABLE_CTRL(boolean ctrlt, boolean ctrly) {
		return LIB$ENABLE_CTRL(ctrlt, ctrly);
	}
	/**
	 * Call LIB$EXPAND_NODENAME to expand nodename.
	 * @param nodnam nodename
	 * @return return status code + expanded node ame
	 * @throws UnsupportedEncodingException if nodename can not be encoded or decoded
	 */
	public static Result<String> LIB__EXPAND_NODENAME(String nodnam) throws UnsupportedEncodingException {
		return LIB$EXPAND_NODENAME(nodnam);
	}
	/**
	 * Class FIND_FILE_CTX represents context for LIB$FIND_FILE and LIB$FIND_FILE_END calls.
	 */
	public static class FIND_FILE_CTX extends dk.vajhoej.vms.call.lib.LIBRTL.FIND_FILE_CTX {
		/**
		 * Construct instance.
		 * @param filespec file specification
		 */
		public FIND_FILE_CTX(String filespec) {
			super(filespec);
		}
		/**
		 * Call LIB$FIND_FILE to get next matching file.
		 * @return return status code + name of matching file
		 * @throws UnsupportedEncodingException if file spec can not be encoded
		 */
		public Result<String> LIB__FIND_FILE() throws UnsupportedEncodingException {
			return LIB$FIND_FILE();
		}
		/**
		 * Call LIB$FIND_FILE_END to end processing.
		 * @return return status code
		 */
		public Result<Void> LIB__FIND_FILE_END() {
			return LIB$FIND_FILE_END();
		}
	}
	/**
	 * Call LIB$GETDVI to get single item as int.
	 * @param code item
	 * @param devnam device name
	 * @return return status code + value
	 * @throws UnsupportedEncodingException if device name can not be encoded
	 */
	public static Result<Integer> LIB__GETDVI_AsInt(String code, String devnam) throws UnsupportedEncodingException {
		return LIB$GETDVI_AsInt(code, devnam);
	}
	/**
	 * Call LIB$GETDVI to get single item as String.
	 * @param code item
	 * @param devnam device name
	 * @return return status code + value
	 * @throws UnsupportedEncodingException if device name can not be encoded or value can not be decoded
	 */
	public static Result<String> LIB__GETDVI_AsString(String code, String devnam) throws UnsupportedEncodingException {
		return LIB$GETDVI_AsString(code, devnam);
	}
	/**
	 * Call LIB$GETJPI to get single item as int.
	 * @param code item
	 * @param pid PID
	 * @return return status code + value
	 * @throws UnsupportedEncodingException will never happen
	 */
	public static Result<Integer> LIB__GETJPI_AsInt(String code, int pid) throws UnsupportedEncodingException {
		return LIB$GETJPI_AsInt(code, pid);
	}
	/**
	 * Call LIB$GETJPI to get single item as String.
	 * @param code item
	 * @param pid PID
	 * @return return status code + value
	 * @throws UnsupportedEncodingException if value can not be decoded
	 */
	public static Result<String> LIB__GETJPI_AsString(String code, int pid) throws UnsupportedEncodingException {
		return LIB$GETJPI_AsString(code, pid);
	}
	/**
	 * Call LIB$GETSYI to get single item as int.
	 * @param code item
	 * @return return status code + value
	 * @throws UnsupportedEncodingException will never happen
	 */
	public static Result<Integer> LIB__GETSYI_AsInt(String code) throws UnsupportedEncodingException {
		return LIB$GETSYI_AsInt(code);
	}
	/**
	 * Call LIB$GETSYI to get single item as String.
	 * @param code item
	 * @return return status code + value
	 * @throws UnsupportedEncodingException if value can not be decoded
	 */
	public static Result<String> LIB__GETSYI_AsString(String code) throws UnsupportedEncodingException {
		return LIB$GETSYI_AsString(code);
	}
	/**
	 * Call LIB$GET_COMMON to load string from common area.
	 * @return return status code + string value
	 * @throws UnsupportedEncodingException if string value can not be decoded
	 */
    public static Result<String> LIB__GET_COMMON() throws UnsupportedEncodingException {
    	return LIB$GET_COMMON();
	}
    /**
     * Call LIB$GET_FOREIGN to get command line arguments.
     * @return return status code + command line arguments
     * @throws UnsupportedEncodingException if command line arguments can not be decoded
     */
	public static Result<String> LIB__GET_FOREIGN() throws UnsupportedEncodingException {
		return LIB$GET_FOREIGN();
	}
	/**
	 * Call LIB$GET_LOGICAL to get value of logical name.
	 * @param lognam logical name
	 * @return return status code + value of logical name
	 * @throws UnsupportedEncodingException if logical name can not be encoded or value can not be decoded
	 */
	public static Result<String> LIB__GET_LOGICAL(String lognam) throws UnsupportedEncodingException {
		return LIB$GET_LOGICAL(lognam);
	}
	/**
	 * Call LIB$GET_SYMBOL to get value of symbol.
	 * @param symnam symbol name
	 * @return return status code + value of symbol
	 * @throws UnsupportedEncodingException if symbol name can not be encoded or value can not be decoded
	 */
    public static Result<String> LIB__GET_SYMBOL(String symnam) throws UnsupportedEncodingException {
    	return LIB$GET_SYMBOL(symnam);
	}
    /**
     * Call LIB$PAUSE to pause.
     * @return return status code
     */
    public static Result<Void> LIB__PAUSE() {
    	return LIB$PAUSE();
    }
    /**
     * Call LIB$PUT_COMMON to save string to common area.
     * @param value string value
     * @return return code
     * @throws UnsupportedEncodingException if string value can not be encoded
     */
    public static Result<Void> LIB__PUT_COMMON(String value) throws UnsupportedEncodingException {
    	return LIB$PUT_COMMON(value);
    }
    /**
     * Call LIB$SET_LOGICAL to define logical.
     * @param lognam logical name
     * @param value value for logical name
     * @return return status code
     * @throws UnsupportedEncodingException if either logical name or value can not be encoded
     */
    public static Result<Void> LIB__SET_LOGICAL(String lognam, String value) throws UnsupportedEncodingException {
    	return LIB$SET_LOGICAL(lognam, value);
    }
    /**
     * Call LIB$SET_LOGICAL to define logical in specific logical table.
     * @param lognam logical name
     * @param value value for logical name
     * @param tblnam logical table name
     * @return return status code
     * @throws UnsupportedEncodingException if either logical name or value can not be encoded
     */
	public static Result<Void> LIB__SET_LOGICAL(String lognam, String value, String tblnam) throws UnsupportedEncodingException {
    	return LIB$SET_LOGICAL(lognam, value, tblnam);
	}
    /**
     * Call LIB$SET_SYMBOL to set symbol.
     * @param symnam symbol name
     * @param value value for lsymbol
     * @return return status code
     * @throws UnsupportedEncodingException if either symbol name or value can not be encoded
     */
    public static Result<Void> LIB__SET_SYMBOL(String symnam, String value) throws UnsupportedEncodingException {
    	return LIB$SET_SYMBOL(symnam, value);
    }
    /**
     * Call LIB$SYS_ASCTIM to format a VMS time.
     * @param vmstime VMS time
     * @return return status code + formatted time
     * @throws UnsupportedEncodingException if formatted time can not be decoded
     */
    public static Result<String> LIB__SYS_ASCTIM(long vmstime) throws UnsupportedEncodingException {
    	return LIB$SYS_ASCTIM(vmstime);
	}
    /**
     * Call LIB$SYS_GETMSG to get message text for error code.
     * @param msgid error code
     * @return return status code
     * @throws UnsupportedEncodingException if message text can not be decoded
     */
    public static Result<String> LIB__SYS_GETMSG(int msgid) throws UnsupportedEncodingException {
    	return LIB$SYS_GETMSG(msgid);
    }
    /**
     * Class TIMER_CTX represent context for LIB$INIT_TIMER and LIB$STAT_TIMER calls.
     */
	public static class TIMER_CTX extends dk.vajhoej.vms.call.script.LIBRTL_Script.TIMER_CTX {
		/**
		 * Call LIB$INIT_TIMER to start timer.
		 * @return return status code
		 */
		public Result<Void> LIB__INIT_TIMER() {
			return LIB$INIT_TIMER();
		}
		/**
		 * Call LIB$STAT_TIMER to get timer values.
		 * @param code code for timer value
		 * @return return status code + timer value
		 */
		public Result<Integer> LIB__STAT_TIMER(String code) {
			return LIB$STAT_TIMER(code);
		}
	}
	/**
	 * Call LIB$WAIT to sleep.
	 * @param seconds number seconds to sleep
	 * @return return status code
	 */
	public static Result<Void> LIB__WAIT(double seconds) {
		return LIB$WAIT(seconds);
	}
	/**
	 * Call LIB$FIND_FILE and LIB$FIND_FILE_END to find all file names matching specification.
	 * @param filespec file name specification
	 * @return Java List with matching file names 
	 * @throws UnsupportedEncodingException if file spec can not be encoded
	 */
	public static List<String> LIB__FIND_FILE(String filespec) throws UnsupportedEncodingException {
		return LIB$FIND_FILE(filespec);
	}
}
